## Readme
This folder contains all components used in this project.

./forms/* contains all the components used exclusively in the backoffice forms, they have already
labels, help texts, etc.

./simple_forms/* contains all the components in a minimized way, created to be used anywhere
